==> openshift-model-6.8.0-sources.jar: io/fabric8/openshift/api/model/ParameterFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ParameterFluent<A extends ParameterFluent<A>> extends BaseFluent<A>{
  public ParameterFluent() {
  }
  public ParameterFluent(Parameter instance) {
    instance = (instance != null ? instance : new Parameter());

    if (instance != null) {
      this.withDescription(instance.getDescription());
      this.withDisplayName(instance.getDisplayName());
      this.withFrom(instance.getFrom());
      this.withGenerate(instance.getGenerate());
      this.withName(instance.getName());
      this.withRequired(instance.getRequired());
      this.withValue(instance.getValue());
      this.withDescription(instance.getDescription());
      this.withDisplayName(instance.getDisplayName());
      this.withFrom(instance.getFrom());
      this.withGenerate(instance.getGenerate());
      this.withName(instance.getName());
      this.withRequired(instance.getRequired());
      this.withValue(instance.getValue());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String description;
  private String displayName;
  private String from;
  private String generate;
  private String name;
  private Boolean required;
  private String value;
  private Map<String,Object> additionalProperties;
  public String getDescription() {
    return this.description;
  }
  public A withDescription(String description) {
    this.description=description; return (A) this;
  }
  public boolean hasDescription() {
    return this.description != null;
  }
  public String getDisplayName() {
    return this.displayName;
  }
  public A withDisplayName(String displayName) {
    this.displayName=displayName; return (A) this;
  }
  public boolean hasDisplayName() {
    return this.displayName != null;
  }
  public String getFrom() {
    return this.from;
  }
  public A withFrom(String from) {
    this.from=from; return (A) this;
  }
  public boolean hasFrom() {
    return this.from != null;
  }
  public String getGenerate() {
    return this.generate;
  }
  public A withGenerate(String generate) {
    this.generate=generate; return (A) this;
  }
  public boolean hasGenerate() {
    return this.generate != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public boolean hasName() {
    return this.name != null;
  }
  public Boolean getRequired() {
    return this.required;
  }
  public A withRequired(Boolean required) {
    this.required=required; return (A) this;
  }
  public boolean hasRequired() {
    return this.required != null;
  }
  public String getValue() {
    return this.value;
  }
  public A withValue(String value) {
    this.value=value; return (A) this;
  }
  public boolean hasValue() {
    return this.value != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ParameterFluent that = (ParameterFluent) o;
    if (!java.util.Objects.equals(description, that.description)) return false;

    if (!java.util.Objects.equals(displayName, that.displayName)) return false;

    if (!java.util.Objects.equals(from, that.from)) return false;

    if (!java.util.Objects.equals(generate, that.generate)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(required, that.required)) return false;

    if (!java.util.Objects.equals(value, that.value)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(description,  displayName,  from,  generate,  name,  required,  value,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (description != null) { sb.append("description:"); sb.append(description + ","); }
    if (displayName != null) { sb.append("displayName:"); sb.append(displayName + ","); }
    if (from != null) { sb.append("from:"); sb.append(from + ","); }
    if (generate != null) { sb.append("generate:"); sb.append(generate + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (required != null) { sb.append("required:"); sb.append(required + ","); }
    if (value != null) { sb.append("value:"); sb.append(value + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withRequired() {
    return withRequired(true);
  }
  
}

==> openshift-model-6.9.0-sources.jar: io/fabric8/openshift/api/model/ParameterFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ParameterFluent<A extends ParameterFluent<A>> extends BaseFluent<A>{
  public ParameterFluent() {
  }
  
  public ParameterFluent(Parameter instance) {
    this.copyInstance(instance);
  }
  private String description;
  private String displayName;
  private String from;
  private String generate;
  private String name;
  private Boolean required;
  private String value;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(Parameter instance) {
    instance = (instance != null ? instance : new Parameter());
  
    if (instance != null) {
        this.withDescription(instance.getDescription());
        this.withDisplayName(instance.getDisplayName());
        this.withFrom(instance.getFrom());
        this.withGenerate(instance.getGenerate());
        this.withName(instance.getName());
        this.withRequired(instance.getRequired());
        this.withValue(instance.getValue());
        this.withDescription(instance.getDescription());
        this.withDisplayName(instance.getDisplayName());
        this.withFrom(instance.getFrom());
        this.withGenerate(instance.getGenerate());
        this.withName(instance.getName());
        this.withRequired(instance.getRequired());
        this.withValue(instance.getValue());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getDescription() {
    return this.description;
  }
  
  public A withDescription(String description) {
    this.description=description; return (A) this;
  }
  
  public boolean hasDescription() {
    return this.description != null;
  }
  
  public String getDisplayName() {
    return this.displayName;
  }
  
  public A withDisplayName(String displayName) {
    this.displayName=displayName; return (A) this;
  }
  
  public boolean hasDisplayName() {
    return this.displayName != null;
  }
  
  public String getFrom() {
    return this.from;
  }
  
  public A withFrom(String from) {
    this.from=from; return (A) this;
  }
  
  public boolean hasFrom() {
    return this.from != null;
  }
  
  public String getGenerate() {
    return this.generate;
  }
  
  public A withGenerate(String generate) {
    this.generate=generate; return (A) this;
  }
  
  public boolean hasGenerate() {
    return this.generate != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public Boolean getRequired() {
    return this.required;
  }
  
  public A withRequired(Boolean required) {
    this.required=required; return (A) this;
  }
  
  public boolean hasRequired() {
    return this.required != null;
  }
  
  public String getValue() {
    return this.value;
  }
  
  public A withValue(String value) {
    this.value=value; return (A) this;
  }
  
  public boolean hasValue() {
    return this.value != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ParameterFluent that = (ParameterFluent) o;
    if (!java.util.Objects.equals(description, that.description)) return false;
  
    if (!java.util.Objects.equals(displayName, that.displayName)) return false;
  
    if (!java.util.Objects.equals(from, that.from)) return false;
  
    if (!java.util.Objects.equals(generate, that.generate)) return false;
  
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(required, that.required)) return false;
  
    if (!java.util.Objects.equals(value, that.value)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(description,  displayName,  from,  generate,  name,  required,  value,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (description != null) { sb.append("description:"); sb.append(description + ","); }
    if (displayName != null) { sb.append("displayName:"); sb.append(displayName + ","); }
    if (from != null) { sb.append("from:"); sb.append(from + ","); }
    if (generate != null) { sb.append("generate:"); sb.append(generate + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (required != null) { sb.append("required:"); sb.append(required + ","); }
    if (value != null) { sb.append("value:"); sb.append(value + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withRequired() {
    return withRequired(true);
  }
  

}
